unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  LogBase, LogFile, ExtCtrls, StdCtrls, LogShell, checklst, ComCtrls, Menus;

type
  TfrmMain = class(TForm)
    pnlToolbar: TPanel;
    lblFolderName: TLabel;
    edFolderName: TEdit;
    SMShellLog: TSMShellLog;
    btnActivate: TButton;
    btnStop: TButton;
    pcLog: TPageControl;
    tsLog: TTabSheet;
    lbLog: TListBox;
    tsOptions: TTabSheet;
    clbOptions: TCheckListBox;
    cbSubFolder: TCheckBox;
    pmOptions: TPopupMenu;
    miSelectAll: TMenuItem;
    miUnSelectAll: TMenuItem;
    miRevertSelection: TMenuItem;
    procedure FormDestroy(Sender: TObject);
    procedure btnActivateClick(Sender: TObject);
    procedure btnStopClick(Sender: TObject);
    procedure SMShellLogAssociationChange(Sender: TObject);
    procedure SMShellLogAttributesChange(Sender: TObject; OldValue,
      NewValue: String);
    procedure SMShellLogDriveAdd(Sender: TObject; Value: String);
    procedure SMShellLogDriveAddGui(Sender: TObject; Value: String);
    procedure SMShellLogDriveRemove(Sender: TObject; Value: String);
    procedure SMShellLogFileCreate(Sender: TObject; Value: String);
    procedure SMShellLogFileDelete(Sender: TObject; Value: String);
    procedure SMShellLogFileRename(Sender: TObject; OldValue,
      NewValue: String);
    procedure SMShellLogFolderCreate(Sender: TObject; Value: String);
    procedure SMShellLogFolderRemove(Sender: TObject; Value: String);
    procedure SMShellLogFolderRename(Sender: TObject; OldValue,
      NewValue: String);
    procedure SMShellLogFolderUpdate(Sender: TObject; Value: String);
    procedure SMShellLogMediaInserted(Sender: TObject; Value: String);
    procedure SMShellLogMediaRemove(Sender: TObject; Value: String);
    procedure SMShellLogNetShare(Sender: TObject; Value: String);
    procedure SMShellLogNetUnShare(Sender: TObject; Value: String);
    procedure SMShellLogServerDisconnect(Sender: TObject; Value: String);
    procedure miSelectAllClick(Sender: TObject);
    procedure miUnSelectAllClick(Sender: TObject);
    procedure miRevertSelectionClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.DFM}

procedure TfrmMain.FormDestroy(Sender: TObject);
begin
  SMShellLog.Active := False
end;

procedure TfrmMain.btnActivateClick(Sender: TObject);
var
  i: Integer;
begin
  {apply all settings}
  SMShellLog.Options := [];
  for i := 0 to clbOptions.Items.Count-1 do
    if clbOptions.Checked[i] then
      SMShellLog.Options := SMShellLog.Options + [TSMLNotificationEvent(i)];

  SMShellLog.Path := edFolderName.Text;
  SMShellLog.WatchSubTree := cbSubFolder.Checked;

  SMShellLog.Active := True;
  btnStop.Enabled := True;
  btnActivate.Enabled := False;

  pcLog.ActivePage := tsLog;
end;

procedure TfrmMain.btnStopClick(Sender: TObject);
begin
  SMShellLog.Active := False;
  btnStop.Enabled := False;
  btnActivate.Enabled := True;
end;

procedure TfrmMain.SMShellLogAssociationChange(Sender: TObject);
begin
  lbLog.Items.Add('AssociationChange');
end;

procedure TfrmMain.SMShellLogAttributesChange(Sender: TObject; OldValue,
  NewValue: String);
begin
  lbLog.Items.Add('AttributesChange (from ' + OldValue + ' to ' + NewValue + ')');
end;

procedure TfrmMain.SMShellLogDriveAdd(Sender: TObject; Value: String);
begin
  lbLog.Items.Add('DriveAdd (' + Value + ')');
end;

procedure TfrmMain.SMShellLogDriveAddGui(Sender: TObject; Value: String);
begin
  lbLog.Items.Add('ShellDriveAdd (' + Value + ')');
end;

procedure TfrmMain.SMShellLogDriveRemove(Sender: TObject; Value: String);
begin
  lbLog.Items.Add('DriveRemove (' + Value + ')');
end;

procedure TfrmMain.SMShellLogFileCreate(Sender: TObject; Value: String);
begin
  lbLog.Items.Add('FileCreate (' + Value + ')');
end;

procedure TfrmMain.SMShellLogFileDelete(Sender: TObject; Value: String);
begin
  lbLog.Items.Add('FileDelete (' + Value + ')');
end;

procedure TfrmMain.SMShellLogFileRename(Sender: TObject; OldValue,
  NewValue: String);
begin
  lbLog.Items.Add('FileRename (from ' + OldValue + ' to ' + NewValue + ')');
end;

procedure TfrmMain.SMShellLogFolderCreate(Sender: TObject; Value: String);
begin
  lbLog.Items.Add('FolderCreate (' + Value + ')');
end;

procedure TfrmMain.SMShellLogFolderRemove(Sender: TObject; Value: String);
begin
  lbLog.Items.Add('FolderRemove (' + Value + ')');
end;

procedure TfrmMain.SMShellLogFolderRename(Sender: TObject; OldValue,
  NewValue: String);
begin
  lbLog.Items.Add('FolderRename (from ' + OldValue + ' to ' + NewValue + ')');
end;

procedure TfrmMain.SMShellLogFolderUpdate(Sender: TObject; Value: String);
begin
  lbLog.Items.Add('FolderUpdate (' + Value + ')');
end;

procedure TfrmMain.SMShellLogMediaInserted(Sender: TObject; Value: String);
begin
  lbLog.Items.Add('MediaInserted (' + Value + ')');
end;

procedure TfrmMain.SMShellLogMediaRemove(Sender: TObject; Value: String);
begin
  lbLog.Items.Add('MediaRemoved (' + Value + ')');
end;

procedure TfrmMain.SMShellLogNetShare(Sender: TObject; Value: String);
begin
  lbLog.Items.Add('NetShare (' + Value + ')');
end;

procedure TfrmMain.SMShellLogNetUnShare(Sender: TObject; Value: String);
begin
  lbLog.Items.Add('NetUnShare (' + Value + ')');
end;

procedure TfrmMain.SMShellLogServerDisconnect(Sender: TObject;
  Value: String);
begin
  lbLog.Items.Add('ServerDisconnect (' + Value + ')');
end;

procedure TfrmMain.miSelectAllClick(Sender: TObject);
var
  i: Integer;
begin
  for i := 0 to clbOptions.Items.Count-1 do
    clbOptions.Checked[i] := True
end;

procedure TfrmMain.miUnSelectAllClick(Sender: TObject);
var
  i: Integer;
begin
  for i := 0 to clbOptions.Items.Count-1 do
    clbOptions.Checked[i] := False
end;

procedure TfrmMain.miRevertSelectionClick(Sender: TObject);
var
  i: Integer;
begin
  for i := 0 to clbOptions.Items.Count-1 do
    clbOptions.Checked[i] := not clbOptions.Checked[i]
end;

end.
